@@ -26,7 +26,7 @@ except:
 # TextIO is missing on some older Pythons.
 if 'TextIO' not in globals():
     try:
-        TextIO = typing.TextIO
+        from typing import TextIO
     except ImportError:
         TextIO = None # type: ignore
 else:
@@ -42,7 +42,7 @@ OutputNormalizer = Callable[[str], str]
 IssueNumber = NewType("IssueNumber", int)
 
 # Used by perf_notes
-GitHash = NewType("GitHash", str)
+GitHash = NewType("GitHash", str) # a Git commit hash
 GitRef = NewType("GitRef", str)
 TestEnv = NewType("TestEnv", str)
-MetricName = NewType("MetricName", str)
\ No newline at end of file
+MetricName = NewType("MetricName", str)
